#[non_exhaustive]pub struct CrossSectionSample {
pub ident: Option<String>,
pub position: GeoPoint,
pub along_track_nm: f64,
pub altitude_ft: f64,
pub eta_from_etd: Duration,
pub phase: FlightPhase,
}Expand description
One sampled point of the vertical profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ident: Option<String>Identifier when the sample sits on a named route waypoint.
position: GeoPointPosition of the sample.
along_track_nm: f64Distance from the departure along the route, nautical miles.
altitude_ft: f64Estimated altitude here, feet MSL.
eta_from_etd: DurationEstimated time from the ETD to here.
phase: FlightPhaseFlight phase here.