RouteError

Enum RouteError 

#[non_exhaustive]
pub enum RouteError { Empty, UnsupportedToken { kind: UnsupportedKind, token: String, }, AirwayAtRouteEdge { airway: String, }, AdjacentAirways { first: String, second: String, }, UnresolvedIdent { ident: String, cycle: NaiveDate, }, UnknownAirway { airway: String, }, EntryFixNotOnAirway { fix: String, airway: String, }, ExitFixNotOnAirway { fix: String, airway: String, }, AmbiguousAirway { airway: String, entry: String, exit: String, }, DiscontinuedSegment { airway: String, from: String, to: String, }, }
Failure parsing or expanding a route string.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

The route string is empty.



UnsupportedToken

A token form v0.1 deliberately does not expand.

Fields

kind: UnsupportedKind

What kind of unsupported form.

token: String

The verbatim token.



AirwayAtRouteEdge

A route may not start or end with an airway designator.

Fields

airway: String

The offending designator.



AdjacentAirways

Two airway designators need a shared transition fix between them.

Fields

first: String

First designator.

second: String

Second designator.



UnresolvedIdent

An identifier is not in the snapshot.

Fields

ident: String

The identifier.

cycle: NaiveDate

The snapshot’s effective date, for the operator.



UnknownAirway

No airway with this designator exists in the snapshot.

Fields

airway: String

The designator.



EntryFixNotOnAirway

The entry fix is not a published point of the airway.

Fields

fix: String

The fix named before the airway.

airway: String

The designator.



ExitFixNotOnAirway

The exit fix is not a published point of the airway.

Fields

fix: String

The fix named after the airway.

airway: String

The designator.



AmbiguousAirway

Both fixes are on more than one airway instance (locations).

Fields

airway: String

The designator.

entry: String

Entry fix.

exit: String

Exit fix.



DiscontinuedSegment

The traversal crosses a published gap.

Fields

airway: String

The designator.

from: String

Last point before the gap.

to: String

First point after the gap.