#[non_exhaustive]pub struct RoutePoint {
pub ident: Option<String>,
pub position: GeoPoint,
pub via_airway: Option<String>,
}Expand description
A route point produced by expansion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ident: Option<String>Published identifier, None for inline lat/lon waypoints.
position: GeoPointResolved position.
via_airway: Option<String>The airway this point was emitted from, when it came from an airway traversal rather than an explicit token.
Implementations
Sourceimpl RoutePoint
impl RoutePoint