#[non_exhaustive]pub enum RouteError {
Empty,
UnsupportedToken {
kind: UnsupportedKind,
token: String,
},
AirwayAtRouteEdge {
airway: String,
},
AdjacentAirways {
first: String,
second: String,
},
UnresolvedIdent {
ident: String,
cycle: NaiveDate,
},
UnknownAirway {
airway: String,
},
EntryFixNotOnAirway {
fix: String,
airway: String,
},
ExitFixNotOnAirway {
fix: String,
airway: String,
},
AmbiguousAirway {
airway: String,
entry: String,
exit: String,
},
DiscontinuedSegment {
airway: String,
from: String,
to: String,
},
}Expand description
Failure parsing or expanding a route string.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The route string is empty.
UnsupportedToken
A token form v0.1 deliberately does not expand.
AirwayAtRouteEdge
A route may not start or end with an airway designator.
AdjacentAirways
Two airway designators need a shared transition fix between them.
UnresolvedIdent
An identifier is not in the snapshot.
Fields
UnknownAirway
No airway with this designator exists in the snapshot.
EntryFixNotOnAirway
The entry fix is not a published point of the airway.
ExitFixNotOnAirway
The exit fix is not a published point of the airway.
AmbiguousAirway
Both fixes are on more than one airway instance (locations).
DiscontinuedSegment
The traversal crosses a published gap.